==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/mixer/adapter/redisquota/RedisquotaFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.redisquota;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import javax.validation.constraints.NotNull;
import java.lang.Deprecated;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class RedisquotaFluentImpl<A extends RedisquotaFluent<A>> extends BaseFluent<A> implements RedisquotaFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private RedisquotaSpecBuilder spec;

    public RedisquotaFluentImpl(){
    }
    public RedisquotaFluentImpl(Redisquota instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public RedisquotaFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public RedisquotaFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public RedisquotaFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public RedisquotaFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public RedisquotaFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public RedisquotaSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public RedisquotaSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(RedisquotaSpec spec){
            _visitables.remove(this.spec);
            if (spec!=null){ this.spec= new RedisquotaSpecBuilder(spec); _visitables.add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public RedisquotaFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public RedisquotaFluent.SpecNested<A> withNewSpecLike(RedisquotaSpec item){
            return new SpecNestedImpl(item);
    }

    public RedisquotaFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public RedisquotaFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new RedisquotaSpecBuilder().build());
    }

    public RedisquotaFluent.SpecNested<A> editOrNewSpecLike(RedisquotaSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            RedisquotaFluentImpl that = (RedisquotaFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<RedisquotaFluent.MetadataNested<N>> implements RedisquotaFluent.MetadataNested<N>,Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) RedisquotaFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends RedisquotaSpecFluentImpl<RedisquotaFluent.SpecNested<N>> implements RedisquotaFluent.SpecNested<N>,Nested<N>{

            private final RedisquotaSpecBuilder builder;
    
            SpecNestedImpl(RedisquotaSpec item){
                    this.builder = new RedisquotaSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new RedisquotaSpecBuilder(this);
            }
    
    public N and(){
            return (N) RedisquotaFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/redisquota/RedisquotaFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.redisquota;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class RedisquotaFluentImpl<A extends RedisquotaFluent<A>> extends BaseFluent<A> implements RedisquotaFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private RedisquotaSpecBuilder spec;

    public RedisquotaFluentImpl(){
    }
    public RedisquotaFluentImpl(Redisquota instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public RedisquotaFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public RedisquotaFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public RedisquotaFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public RedisquotaFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public RedisquotaFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public RedisquotaSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public RedisquotaSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(RedisquotaSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new RedisquotaSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public RedisquotaFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public RedisquotaFluent.SpecNested<A> withNewSpecLike(RedisquotaSpec item){
            return new SpecNestedImpl(item);
    }

    public RedisquotaFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public RedisquotaFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new RedisquotaSpecBuilder().build());
    }

    public RedisquotaFluent.SpecNested<A> editOrNewSpecLike(RedisquotaSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            RedisquotaFluentImpl that = (RedisquotaFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<RedisquotaFluent.MetadataNested<N>> implements RedisquotaFluent.MetadataNested<N>,Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) RedisquotaFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends RedisquotaSpecFluentImpl<RedisquotaFluent.SpecNested<N>> implements RedisquotaFluent.SpecNested<N>,Nested<N>{

            private final RedisquotaSpecBuilder builder;
    
            SpecNestedImpl(RedisquotaSpec item){
                    this.builder = new RedisquotaSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new RedisquotaSpecBuilder(this);
            }
    
    public N and(){
            return (N) RedisquotaFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}


}
